==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/40/407928f0586e8eba3a63b9494e2ce519.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/PointBundle/EventListener/GroupScoreSubscriber.php */
class __TwigTemplate_2010ec6e8d57c91d711d0402828508d0 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\PointBundle\\EventListener;

use Mautic\\PointBundle\\Event\\GroupScoreChangeEvent;
use Mautic\\PointBundle\\Model\\TriggerModel;
use Mautic\\PointBundle\\PointGroupEvents;
use Symfony\\Component\\EventDispatcher\\EventSubscriberInterface;

class GroupScoreSubscriber implements EventSubscriberInterface
{
    public function __construct(
        private TriggerModel \$triggerModel
    ) {
    }

    public static function getSubscribedEvents(): array
    {
        return [
            PointGroupEvents::SCORE_CHANGE     => ['onGroupScoreChange', 0],
        ];
    }

    public function onGroupScoreChange(GroupScoreChangeEvent \$event): void
    {
        \$this->triggerModel->triggerEvents(\$event->getContact());
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/PointBundle/EventListener/GroupScoreSubscriber.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/PointBundle/EventListener/GroupScoreSubscriber.php", "/var/www/html/mauticGIT-Test/app/bundles/PointBundle/EventListener/GroupScoreSubscriber.php");
    }
}

==> production-demo-20260210_204327.tar.gz: var/www/html/production-demo/var/tmp/twig/40/407928f0586e8eba3a63b9494e2ce519.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/PointBundle/EventListener/GroupScoreSubscriber.php */
class __TwigTemplate_2010ec6e8d57c91d711d0402828508d0 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\PointBundle\\EventListener;

use Mautic\\PointBundle\\Event\\GroupScoreChangeEvent;
use Mautic\\PointBundle\\Model\\TriggerModel;
use Mautic\\PointBundle\\PointGroupEvents;
use Symfony\\Component\\EventDispatcher\\EventSubscriberInterface;

class GroupScoreSubscriber implements EventSubscriberInterface
{
    public function __construct(
        private TriggerModel \$triggerModel
    ) {
    }

    public static function getSubscribedEvents(): array
    {
        return [
            PointGroupEvents::SCORE_CHANGE     => ['onGroupScoreChange', 0],
        ];
    }

    public function onGroupScoreChange(GroupScoreChangeEvent \$event): void
    {
        \$this->triggerModel->triggerEvents(\$event->getContact());
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/PointBundle/EventListener/GroupScoreSubscriber.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/PointBundle/EventListener/GroupScoreSubscriber.php", "/var/www/html/production-demo/app/bundles/PointBundle/EventListener/GroupScoreSubscriber.php");
    }
}
